@@ -841,6 +841,16 @@ class TestSearchTemplate(unittest.TestCase):
 class TestReplaceTemplate(unittest.TestCase):
     """Test replace template."""
 
+    def test_format_existing_group_no_match(self):
+        """Test format replacement with existing group with no match."""
+
+        self.assertEqual(bre.compile(r'(test)|(what)').subf(r'{1}{2}', 'test'), 'test')
+
+    def test_existing_group_no_match(self):
+        """Test existing group with no match."""
+
+        self.assertEqual(bre.compile(r'(test)|(what)').sub(r'\2', 'test'), '')
+
     def test_hash(self):
         """Test hashing of replace."""
 
@@ -910,6 +920,11 @@ class TestReplaceTemplate(unittest.TestCase):
         with pytest.raises(TypeError):
             bre.subf(b'test', br'{[test]}', b'test', bre.FORMAT)
 
+    def test_format_ascii_align(self):
+        """Test format ASCII."""
+
+        self.assertEqual(bre.subf('test', r'{0!a:|^8}', 'test'), "|'test'|")
+
     def test_format_conversions(self):
         """Test string format conversion paths."""
 
@@ -997,13 +1012,13 @@ class TestReplaceTemplate(unittest.TestCase):
 
         pattern = re.compile(r"(some)(.+?)(pattern)(!)")
         with pytest.raises(sre_constants.error):
-            _bre_parse._ReplaceParser().parse(pattern, '\\1\\l\\')
+            _bre_parse._ReplaceParser(pattern, '\\1\\l\\').parse()
 
         with pytest.raises(sre_constants.error):
-            _bre_parse._ReplaceParser().parse(pattern, '\\1\\L\\')
+            _bre_parse._ReplaceParser(pattern, '\\1\\L\\').parse()
 
         with pytest.raises(sre_constants.error):
-            _bre_parse._ReplaceParser().parse(pattern, '\\1\\')
+            _bre_parse._ReplaceParser(pattern, '\\1\\').parse()
 
     def test_line_break(self):
         r"""Test line break \R."""
@@ -1134,8 +1149,8 @@ class TestReplaceTemplate(unittest.TestCase):
         """Test retrieval of the replace template original string."""
 
         pattern = re.compile(r"(some)(.+?)(pattern)(!)")
-        template = _bre_parse._ReplaceParser()
-        template.parse(pattern, r'\c\1\2\C\3\E\4')
+        template = _bre_parse._ReplaceParser(pattern, r'\c\1\2\C\3\E\4')
+        template.parse()
 
         self.assertEqual(r'\c\1\2\C\3\E\4', template.get_base_template())
 
@@ -1578,7 +1593,7 @@ class TestReplaceTemplate(unittest.TestCase):
 
         text = "Replace with function test!"
         pattern = bre.compile_search('(.+)')
-        repl = _bre_parse._ReplaceParser().parse(pattern, 'Success!')
+        repl = _bre_parse._ReplaceParser(pattern, 'Success!').parse()
         expand = bre.compile_replace(pattern, repl)
 
         m = pattern.match(text)
@@ -1712,7 +1727,7 @@ class TestReplaceTemplate(unittest.TestCase):
         )
         results = expand(pattern.match(text))
         self.assertEqual(
-            'ba',
+            'ababababab',
             results
         )
 
@@ -1744,7 +1759,7 @@ class TestReplaceTemplate(unittest.TestCase):
         )
 
         results = expand(pattern.match(text))
-        self.assertEqual(b'989898', results)
+        self.assertEqual(b'bbb', results)
 
     def test_format_escapes(self):
         """Test format escapes."""
@@ -1970,6 +1985,12 @@ class TestReplaceTemplate(unittest.TestCase):
 class TestExceptions(unittest.TestCase):
     """Test Exceptions."""
 
+    def test_format_existing_group_no_match_with_index(self):
+        """Test format group with no match and attempt at indexing."""
+
+        with pytest.raises(IndexError):
+            bre.compile(r'(test)|(what)').subf(r'{2[0]}', 'test')
+
     def test_immutable(self):
         """Test immutable object."""
 
@@ -2125,7 +2146,7 @@ class TestExceptions(unittest.TestCase):
         """Test when a compile occurs on a template with flags passed."""
 
         pattern = re.compile('test')
-        template = _bre_parse._ReplaceParser().parse(pattern, 'whatever')
+        template = _bre_parse._ReplaceParser(pattern, 'whatever').parse()
 
         with pytest.raises(ValueError) as excinfo:
             bre.compile_replace(pattern, template, bre.FORMAT)
