@@ -20,6 +20,13 @@ PY39_PLUS = (3, 9) <= sys.version_info
 class TestSearchTemplate(unittest.TestCase):
     """Search template tests."""
 
+    def test_named_lists_attribute(self):
+        """Test named list attribute."""
+
+        pattern1 = bregex.compile(r'\L<name>', name=['blue', 'green'])
+        pattern2 = regex.compile(r'\L<name>', name=['blue', 'green'])
+        self.assertEqual(pattern1.named_lists, pattern2.named_lists)
+
     def test_named_lists(self):
         """Test named lists."""
 
@@ -603,6 +610,16 @@ class TestSearchTemplate(unittest.TestCase):
 class TestReplaceTemplate(unittest.TestCase):
     """Test replace template."""
 
+    def test_format_existing_group_no_match(self):
+        """Test format replacement with existing group with no match."""
+
+        self.assertEqual(bregex.compile(r'(test)|(what)').subf(r'{1}{2}', 'test'), 'test')
+
+    def test_existing_group_no_match(self):
+        """Test existing group with no match."""
+
+        self.assertEqual(bregex.compile(r'(test)|(what)').sub(r'\2', 'test'), '')
+
     def test_hash(self):
         """Test hashing of replace."""
 
@@ -759,13 +776,13 @@ class TestReplaceTemplate(unittest.TestCase):
 
         pattern = regex.compile(r"(some)(.+?)(pattern)(!)")
         with pytest.raises(_regex_core.error):
-            _bregex_parse._ReplaceParser().parse(pattern, '\\1\\l\\')
+            _bregex_parse._ReplaceParser(pattern, '\\1\\l\\').parse()
 
         with pytest.raises(_regex_core.error):
-            _bregex_parse._ReplaceParser().parse(pattern, '\\1\\L\\')
+            _bregex_parse._ReplaceParser(pattern, '\\1\\L\\').parse()
 
         with pytest.raises(_regex_core.error):
-            _bregex_parse._ReplaceParser().parse(pattern, '\\1\\')
+            _bregex_parse._ReplaceParser(pattern, '\\1\\').parse()
 
     def test_line_break(self):
         r"""Test line break \R."""
@@ -844,8 +861,8 @@ class TestReplaceTemplate(unittest.TestCase):
         """Test retrieval of the replace template original string."""
 
         pattern = regex.compile(r"(some)(.+?)(pattern)(!)")
-        template = _bregex_parse._ReplaceParser()
-        template.parse(pattern, r'\c\1\2\C\3\E\4')
+        template = _bregex_parse._ReplaceParser(pattern, r'\c\1\2\C\3\E\4')
+        template.parse()
 
         self.assertEqual(r'\c\1\2\C\3\E\4', template.get_base_template())
 
@@ -1285,7 +1302,7 @@ class TestReplaceTemplate(unittest.TestCase):
 
         text = "Replace with template test!"
         pattern = bregex.compile_search('(.+)')
-        repl = _bregex_parse._ReplaceParser().parse(pattern, 'Success!')
+        repl = _bregex_parse._ReplaceParser(pattern, 'Success!').parse()
         expand = bregex.compile_replace(pattern, repl)
 
         m = pattern.match(text)
@@ -1676,6 +1693,12 @@ class TestReplaceTemplate(unittest.TestCase):
 class TestExceptions(unittest.TestCase):
     """Test Exceptions."""
 
+    def test_format_existing_group_no_match_with_index(self):
+        """Test format group with no match and attempt at indexing."""
+
+        with pytest.raises(IndexError):
+            bregex.compile(r'(test)|(what)').subf(r'{2[0]}', 'test')
+
     def test_immutable(self):
         """Test immutable object."""
 
@@ -1795,7 +1818,7 @@ class TestExceptions(unittest.TestCase):
         """Test when a compile occurs on a template with flags passed."""
 
         pattern = regex.compile('test')
-        template = _bregex_parse._ReplaceParser().parse(pattern, 'whatever')
+        template = _bregex_parse._ReplaceParser(pattern, 'whatever').parse()
 
         with pytest.raises(ValueError) as excinfo:
             bregex.compile_replace(pattern, template, bregex.FORMAT)
